@@ -1,5 +1,5 @@
 package Kephra::App::Panel::Notepad;
-our $VERSION = '0.14';
+our $VERSION = '0.16';
 
 use strict;
 use warnings;
@@ -71,9 +71,6 @@ sub create {
 						? Kephra::Edit::Search::set_replace_item($sel)
 						: Kephra::Edit::Search::set_find_item($sel);
 				}
-			} elsif ($key == &Wx::WXK_F4) {
-				Wx::Window::SetFocus( $ep );
-				switch_visibility() if $event->ControlDown;
 			} elsif ($key == &Wx::WXK_F5) {
 				my ( $sel_beg, $sel_end ) = $notepad->GetSelection;
 				Kephra::App::Panel::Output::ensure_visibility();
@@ -89,12 +86,17 @@ sub create {
 					$result = `$interpreter $code`;
 				}
 				Kephra::App::Panel::Output::say($result);
+			} elsif ($key == &Wx::WXK_F12) {
+				Wx::Window::SetFocus( $ep );
+				switch_visibility() if $event->ControlDown;
+			} elsif ($key == 70 and $event->ControlDown) {# F
+				Kephra::CommandList::run_cmd_by_id('view-searchbar-goto');
 			}
 			$event->Skip;
 	});	
 
-	Kephra::EventTable::add_call
-		( 'app.splitter.right.changed', 'panel_notepad', sub {
+	Kephra::EventTable::add_call (
+		'app.splitter.right.changed', 'panel_notepad', sub {
 			if ( get_visibility() and not _splitter()->IsSplit() ) {
 				show( 0 );
 				return;
@@ -134,15 +136,16 @@ sub note {
 	Wx::Window::SetFocus( _ref() );
 }
 
-sub append_selection {
-	my $selection = Kephra::Edit::get_selection();
-	return unless defined $selection and $selection;
+sub append {
+	my $text = shift;
+	return unless defined $text and $text;
 	my $np = _ref();
-	my $size = $np->GetLength();
-	$selection = "\n".$selection if $size;
-	$np->InsertText( $size, $selection );
+	$text = "\n" . $text if $np->GetLength();
+	$np->AppendText( $text );
 }
 
+sub append_selection { append( Kephra::Edit::get_selection() ) }
+
 sub save {
 	my $file_name = _config()->{content_file};
 	if ($file_name) {
@@ -160,3 +163,11 @@ sub save_size {
 }
 
 1;
+
+=head1 NAME
+
+Kephra::App::Panel::Notepad - notepad panel
+
+=head1 DESCRIPTION
+
+=cut
\ No newline at end of file
