@@ -233,8 +233,8 @@ sub get {
 				},
 				select => {
 					document => 'Select All',
-					toggle => 'Toggle',
-					content => 'Item',
+					'toggle-simple' => 'Toggle',
+					'toggle-content' => 'Item',
 				},
 				search => {
 					'attribute' => {
@@ -700,8 +700,8 @@ sub get {
 				},
 				select => {
 					document => 'select entire document',
-					toggle => 'toggle between selectin a word, a line, a block or nothing',
-					content => 'toggle selection between contents of braces or quotings',
+					'toggle-simple' => 'toggle between selectin a word, a line, a block or nothing',
+					'toggle-content' => 'toggle selection between contents of braces or quotings',
 				},
 				search => {
 					attribute => {
@@ -1117,7 +1117,6 @@ sub get {
 				overwrite => 'Overwrite',
 				reload => 'Reload',
 				restore => 'Restore',
-				select => 'Select',
 				save => 'Save',
 				save_reload => 'Save as ... and Reload',
 				select => 'Select',
