@@ -1,5 +1,5 @@
 package Kephra::Edit;
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use strict;
 use warnings;
@@ -256,22 +256,11 @@ sub insert {
 	my $ep = _ep_ref();
 	$pos = $ep->GetCurrentPos unless defined $pos;
 	$ep->InsertText($pos, $text);
+	$pos += length $text;
+	$ep->SetSelection($pos, $pos);
 }
 sub insert_text   { insert(@_) }
 sub insert_at_pos { insert(@_) }
-sub insert_selection_at_cursor {
-	my $event = shift;
-	my $ep = shift || _ref();
-	return unless ref $event eq 'Wx::MouseEvent' and Kephra::App::EditPanel::is($ep);
-	my $pos = $ep->PositionFromPointClose($event->GetX, $event->GetY);
-	$pos = $ep->GetLineEndPosition(
-		$ep->LineFromPosition(
-			$ep->PositionFromPointClose(
-				Kephra::App::EditPanel::Margin::width() + 2,
-				$event->GetY
-	))) if $pos == -1;
-	$ep->InsertText($pos, $ep->GetSelectedText()) if $pos > -1;
-}
 #
 # Edit Line
 #
@@ -307,53 +296,6 @@ sub del_line_left   {_ep_ref()->DelLineLeft() }
 sub del_line_right  {_ep_ref()->DelLineRight()}
 
 sub eval_newline_sub{}
-
-#
-# special edit functions
-#
-sub copy_surrounding_string { # Edit String (surrounding string encapsulated by "" or '')
-	my $ep = _ep_ref();
-	my $pos  = $ep->GetCurrentPos;
-	my $line = $ep->GetCurrentLine;
-	my $lpos = $ep->PositionFromLine($line);
-	my $befor_text = $ep->GetTextRange($lpos, $pos);
-	my $after_text = $ep->GetTextRange($pos+1, $ep->GetLineEndPosition($line));
-	my $sq_start = rindex $befor_text, '\'';
-	my $sq_stop  = index $after_text, '\'';
-	my $dq_start = rindex $befor_text, '"';
-	my $dq_stop  = index $after_text, '"';
-	return if  ($sq_start == -1 or $sq_stop == -1) 
-	       and ($dq_start == -1 or $dq_stop == -1);
-	_save_positions();
-	if ($sq_start > $dq_start){$ep->SetSelection($lpos+$sq_start+1, $pos+$sq_stop+1)}
-	else                      {$ep->SetSelection($lpos+$dq_start+1, $pos+$dq_stop+1)}
-	copy();
-	_restore_positions();
-}
-
-sub insert_last_perl_var {
-	my $ep = _ep_ref();
-	my $lnr = $ep->GetCurrentLine;
-	return unless $lnr;
-	my $pos  = $ep->GetCurrentPos;
-	my $var;     # store catched var name into that scalar
-	my $nl = ''; # namespace level, how nested is current ns?
-	while (1){
-		# go up and get me the conent of the line
-		my $line = $ep->GetLine(--$lnr);
-		# catch the perl var
-		my $result = $line =~ /([\$@%]\w+)[\[{ -=\(\r\n]/;
-		$nl++ if $line =~ /^\s*\}/;
-		$nl-- if $line =~ /\{\s*(#.*)?$/;
-		$var = $nl ? '' : $1;
-		# exit loop if found something in this , no subnamespace,
-		# or reached end of file or end of block
-		last if $var or $lnr == 0 or ($nl and $nl < 0);
-	}
-	return unless $var;
-	$ep->InsertText( $pos, $var);
-	$ep->GotoPos($pos + length $var);
-}
 1;
 
 =head1 NAME
